@@ -1,21 +1,23 @@
 package Org::To::HTML::Link::cpandist;
-{
-  $Org::To::HTML::Link::cpandist::VERSION = '0.07';
-}
+
+our $VERSION = '0.08'; # VERSION
+
 1;
+# ABSTRACT: cpandist
 
 __END__
+
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
-Org::To::HTML::Link::cpandist
+Org::To::HTML::Link::cpandist - cpandist
 
 =head1 VERSION
 
-version 0.07
-
-=head1 FUNCTIONS
+version 0.08
 
 =head1 AUTHOR
 
@@ -23,10 +25,16 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut
+=head1 DESCRIPTION
 
+=head1 FUNCTIONS
+
+
+None are exported by default, but they are exportable.
+
+=cut
